#!/bin/bash

VERSAO_JAVA="1.6"

function instalarLink() {

    titulo=$1;
    origem=$2;
    destino=$3;
    nomeLink=$4;

    ls ${origem} >stdout-redirect 2> /dev/null

    if [ $? -eq 0 ]; then
        echo -e "\n###################################################################################################";
        echo -e "${titulo}";
        ln -s ${origem} ${destino}
        echo -e "O seguinte link ${nomeLink} foi criado na pasta ${destino} apontando para ${origem}";
        echo -e "###################################################################################################\n";
    else

	ls "${destino}/${nomeLink}" >stdout-redirect 2> /dev/null

	if [ $? -ne 0 ]; then
            echo -e "\n###################################################################################################";
	    echo -e "AVISO: Não foi encontrado nenhuma referência do arquivo \"${nomeLink}\" na pasta \"${destino}\". \nPor favor, procurar o arquivo e incluir na pasta \"${destino}\".\nA instalação será continuada.";
        echo -e "###################################################################################################\n";
	fi
    fi
    rm stdout-redirect
}

function instalarBibliotecasApplet() {
    bash $(dirname $0)/instalador_applet.sh
}

function reiniciarServico() {
   titulo=$1;
   aplicativo=$2;

    echo -e "\n###################################################################################################";
    echo -e "${titulo}";
    echo -e "###################################################################################################\n";

   /etc/init.d/${aplicativo} restart
}

function instalarApplet() {
    echo -e "Preparando para instalar a applet:";

    instalarLink "Instalando um link simbólico para que os smartcard padrão PKCS11 possam ser utilizados pelo OpenSC" /usr/lib/pkcs11/opensc-pkcs11.so /usr/lib opensc-pkcs11.so;

    reiniciarServico "Reiniciando o aplicativo de controle do smartcard (pcscd)" pcscd

    instalarBibliotecasApplet;

    procedimentoFinalizarInstalacao "Procedimentos para completar a instalação";
}

function desinstalarApplet() {

    echo -e "\n###################################################################################################";
    echo -e "Iniciando a Desinstalação";
    echo -e "###################################################################################################\n";

    unlink /usr/lib/opensc-pkcs11.so 2> /dev/null

    ./instalador_applet.sh desinstalar

    echo -e "\n###################################################################################################";
    echo -e "\tA desinstalação foi completada";
    echo -e "###################################################################################################\n";
}

function procedimentoFinalizarInstalacao() {
    titulo=$1;

    echo -e "\n###################################################################################################";
    echo -e "${titulo}";
    echo -e "###################################################################################################\n";

    echo -e "1 - Execute o Firefox";
    echo -e "2 - Abrir o menu \"Editar\" --> \"Preferências\" --> \"Avançado\" --> \"Criptografia\" --> \"Disp. de Segurança\"";
    echo -e "3 - Clicar no botão \"Carregar\" e clicar em \"Procurar\" e procurar pelo caminho \"/usr/lib/opensc-pkcs11.so\".";
    echo -e "4 - Ao perguntar se deseja instalar. Confirmar a instalação.";
    echo -e "5 - Ao finalizar a instalação, acesse o sítio da caixa no seguinte link: http://icp.caixa.gov.br.";
    echo -e "6 - Clicar no link: \"Certificados da Caixa\".";
    echo -e "7 - * Clicar no link: \"Certificado Digital da AC Raiz Brasileira\".";
    echo -e "8 - * Clicar no link: \"Certificado Digital da AC Caixa\".";
    echo -e "9 - * Clicar no link \"Certificado Digital da AC Caixa - Pessoa Física.\" \n\n* OBS: Verificar se o seu certificado foi emitido antes de 30/06/2995 ou depois de 01/07/2005.\n* Marcar como Trust ao aceitar o certificado.";

    echo -e "\nApós finalizar estes passos, seu computador poderá estar pronto para fazer o uso do leitor.";

    echo -e "\n\n** OBS: Caso a leitora esteja piscando a luz, reiniciar o serviço que comunica com a leitora.";
    echo -e "\nDigite o seguinte comando no console/terminal com permissão de root : \n\t/etc/init.d/pcscd restart.";

    echo -e "\n\n** OBS2: Caso precise ler estas informações novamente, execute: \n\t$0 ajuda ";

}

function verificaVersaoJava() {
	java -version 2>&1 | grep --regexp="$VERSAO_JAVA" &> /dev/null
	if [ $? -ne 0 ]; then
	   echo -e "\n###################################################################################################";
   	   echo -e "\tAVISO: Não foi encontrado a versão ${VERSAO_JAVA}.X do Java. \n\n\tPor favor, configurar o sistema para utilizar a versão 1.6 do java";
           echo -e "###################################################################################################\n";

           exit 1;
	fi
}

verificaVersaoJava;
if [ $UID -ne 0 ]; then

   echo -e "\n###################################################################################################";
   echo -e "\tAVISO: Este aplicativo deve ser executado com permissão de root";
   echo -e "###################################################################################################\n";

elif [ $# -ne 1 ]; then
    instalarApplet;

elif [ $1 == "desinstalar" ]; then
    desinstalarApplet;
elif [ $1 == "ajuda" ]; then
    procedimentoFinalizarInstalacao "Procedimentos para completar a instalação";
else
    echo -e "OPÇÃO DESCONHECIDA!\n\n* Parâmetros conhecidos:"
    echo -e "\n\t1- Sem Parâmetro para instalar as bibliotecas necessárias para o funcionamento do applet";
    echo -e "\n\t2- Paramêtro: \"desinstalar\" . Desinstala as bibliotecas.";

fi
echo -e "\n\n\n\n";

exit 0;
